==> apache-druid-33.0.0-src.tar.gz: apache-druid-33.0.0-src/server/src/main/java/org/apache/druid/metadata/MetadataSupervisorManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.metadata;

import org.apache.druid.indexing.overlord.supervisor.SupervisorSpec;
import org.apache.druid.indexing.overlord.supervisor.VersionedSupervisorSpec;

import java.util.List;
import java.util.Map;

public interface MetadataSupervisorManager
{
  void start();

  void insert(String id, SupervisorSpec spec);

  Map<String, List<VersionedSupervisorSpec>> getAll();

  List<VersionedSupervisorSpec> getAllForId(String id);

  /**
   * Return latest supervisors (both active and terminated)
   *
   * @return latest terminated supervisors
   */
  Map<String, SupervisorSpec> getLatest();

  /**
   * Only return the latest active supervisors
   *
   * @return latest active supervisors
   */
  Map<String, SupervisorSpec> getLatestActiveOnly();

  /**
   * Only return the latest terminated supervisors
   *
   * @return latest terminated supervisors
   */
  Map<String, SupervisorSpec> getLatestTerminatedOnly();

  /**
   * Remove terminated supervisors created before the given timestamp.
   *
   * @param timestamp timestamp in milliseconds
   * @return number of supervisor removed
   */
  int removeTerminatedSupervisorsOlderThan(long timestamp);
}

==> apache-druid-35.0.0-src.tar.gz: apache-druid-35.0.0-src/server/src/main/java/org/apache/druid/metadata/MetadataSupervisorManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.metadata;

import org.apache.druid.indexing.overlord.supervisor.SupervisorSpec;
import org.apache.druid.indexing.overlord.supervisor.VersionedSupervisorSpec;

import javax.annotation.Nullable;
import java.util.List;
import java.util.Map;

public interface MetadataSupervisorManager
{
  void start();

  void insert(String id, SupervisorSpec spec);

  Map<String, List<VersionedSupervisorSpec>> getAll();

  /**
   * Get supervisor history for a given supervisor ID with an optional limit
   *
   * @param id the supervisor ID
   * @param limit maximum number of history entries to return (null for all entries)
   * @return list of versioned supervisor specs for the given ID
   */
  List<VersionedSupervisorSpec> getAllForId(String id, @Nullable Integer limit);

  /**
   * Return latest supervisors (both active and terminated)
   *
   * @return latest terminated supervisors
   */
  Map<String, SupervisorSpec> getLatest();

  /**
   * Only return the latest active supervisors
   *
   * @return latest active supervisors
   */
  Map<String, SupervisorSpec> getLatestActiveOnly();

  /**
   * Only return the latest terminated supervisors
   *
   * @return latest terminated supervisors
   */
  Map<String, SupervisorSpec> getLatestTerminatedOnly();

  /**
   * Remove terminated supervisors created before the given timestamp.
   *
   * @param timestamp timestamp in milliseconds
   * @return number of supervisor removed
   */
  int removeTerminatedSupervisorsOlderThan(long timestamp);
}
